#ifndef ABOUT_H
#define ABOUT_H

#include <QDialog>
#include <QtNetwork>

namespace Ui {
    class About;
}

class About : public QDialog {
    Q_OBJECT
public:
    About(QWidget *parent = 0);
    ~About();

protected:
    void changeEvent(QEvent *e);

private:
    Ui::About *ui;

private slots:
    void on_textBrowser_anchorClicked(QUrl );
};

#endif // ABOUT_H
